@@ -48,7 +48,7 @@ use SNMP::Info::LLDP;
 
 use vars qw/$VERSION %GLOBALS %FUNCS %MIBS %MUNGE/;
 
-$VERSION = '3.11';
+$VERSION = '3.20';
 
 %MIBS = (
     %SNMP::Info::Layer3::MIBS,
@@ -809,7 +809,7 @@ sub agg_ports {
   foreach my $m (keys %$trunks) {
       my $skip = 0;
       while (my $s = unpack("x${skip}n2", $trunks->{$m})) {
-          $ret->{ $ports->{$s} } = $m;
+          $ret->{ $ports->{$s} } = $ports->{$m};
           $skip += 2;
       }
   }
